@@ -7,17 +7,13 @@
 from __future__ import annotations
 
 import importlib
+import importlib.metadata
 import inspect
 import os
 import sys
 import warnings
 from pathlib import Path
 
-if sys.version_info < (3, 8):
-    import importlib_metadata
-else:
-    import importlib.metadata as importlib_metadata
-
 try:
     import scikit_build_core
 except ModuleNotFoundError:
@@ -32,7 +28,7 @@ try:
     from scikit_build_core import __version__ as version
 except ModuleNotFoundError:
     try:
-        version = importlib_metadata.version("scikit_build_core")
+        version = importlib.metadata.version("scikit_build_core")
     except ModuleNotFoundError:
         msg = (
             "Package should be installed to produce documentation! "
@@ -71,6 +67,7 @@ extensions = [
     "sphinx_autodoc_typehints",
     "conftabs",
     "sphinx-jsonschema",
+    "sphinx_tippy",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -98,6 +95,12 @@ intersphinx_mapping = {
     "setuptools": ("https://setuptools.pypa.io/en/latest", None),
     "hatchling": ("https://hatch.pypa.io/latest", None),
 }
+tippy_rtd_urls = [
+    val[0]
+    for key, val in intersphinx_mapping.items()
+    # Only works with RTD hosted intersphinx
+    if key not in ("hatchling", "python")
+]
 
 nitpick_ignore = [
     ("py:class", "setuptools.dist.Distribution"),
