@@ -3,7 +3,6 @@ from __future__ import annotations
 import ast
 import dataclasses
 import inspect
-import sys
 import textwrap
 from pathlib import Path
 from typing import TYPE_CHECKING
@@ -24,10 +23,6 @@ def __dir__() -> list[str]:
 
 
 def _get_value(value: ast.expr) -> str:
-    if sys.version_info < (3, 8):
-        assert isinstance(value, ast.Str)
-        return value.s
-
     assert isinstance(value, ast.Constant)
     assert isinstance(value.value, str)
     return value.value
@@ -69,13 +64,14 @@ def mk_docs(dc: type[object], prefix: str = "") -> Generator[DCDoc, None, None]:
     docs = pull_docs(dc)
 
     for field in dataclasses.fields(dc):
-        if dataclasses.is_dataclass(field.type):
-            yield from mk_docs(field.type, prefix=f"{prefix}{field.name}.")
+        field_type = field.type
+        if isinstance(field_type, type) and dataclasses.is_dataclass(field_type):
+            yield from mk_docs(field_type, prefix=f"{prefix}{field.name}.")
             continue
 
         if get_origin(field.type) is list:
             field_type = get_args(field.type)[0]
-            if dataclasses.is_dataclass(field_type):
+            if isinstance(field_type, type) and dataclasses.is_dataclass(field_type):
                 yield from mk_docs(field_type, prefix=f"{prefix}{field.name}[].")
                 continue
 
