@@ -1,16 +1,17 @@
 import dataclasses
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Literal, Optional, Union
 
 from packaging.specifiers import SpecifierSet
 from packaging.version import Version
 
-from .._compat.typing import Annotated, Literal
+from .._compat.typing import Annotated
 
 __all__ = [
     "BackportSettings",
     "BuildSettings",
     "CMakeSettings",
+    "CMakeSettingsDefine",
     "EditableSettings",
     "GenerateSettings",
     "InstallSettings",
@@ -19,6 +20,7 @@ __all__ = [
     "NinjaSettings",
     "SDistSettings",
     "ScikitBuildSettings",
+    "SearchSettings",
     "WheelSettings",
 ]
 
@@ -27,6 +29,28 @@ def __dir__() -> List[str]:
     return __all__
 
 
+class CMakeSettingsDefine(str):
+    """
+    A str subtype for automatically normalizing bool and list values
+    to the CMake representation in the `cmake.define` settings key.
+    """
+
+    json_schema = Union[str, bool, List[str]]
+
+    def __new__(cls, raw: Union[str, bool, List[str]]) -> "CMakeSettingsDefine":
+        def escape_semicolons(item: str) -> str:
+            return item.replace(";", r"\;")
+
+        if isinstance(raw, bool):
+            value = "TRUE" if raw else "FALSE"
+        elif isinstance(raw, list):
+            value = ";".join(map(escape_semicolons, raw))
+        else:
+            value = raw
+
+        return super().__new__(cls, value)
+
+
 @dataclasses.dataclass
 class CMakeSettings:
     minimum_version: Optional[Version] = None
@@ -49,7 +73,7 @@ class CMakeSettings:
     in config or envvar will override toml. See also ``cmake.define``.
     """
 
-    define: Annotated[Dict[str, Union[str, bool]], "EnvVar"] = dataclasses.field(
+    define: Annotated[Dict[str, CMakeSettingsDefine], "EnvVar"] = dataclasses.field(
         default_factory=dict
     )
     """
@@ -80,6 +104,14 @@ class CMakeSettings:
     """
 
 
+@dataclasses.dataclass
+class SearchSettings:
+    site_packages: bool = True
+    """
+    Add the python build environment site_packages folder to the CMake prefix paths.
+    """
+
+
 @dataclasses.dataclass
 class NinjaSettings:
     minimum_version: Optional[Version] = None
@@ -154,7 +186,7 @@ class WheelSettings:
     py_api: str = ""
     """
     The Python tags. The default (empty string) will use the default Python
-    version. You can also set this to "cp37" to enable the CPython 3.7+ Stable
+    version. You can also set this to "cp38" to enable the CPython 3.8+ Stable
     ABI / Limited API (only on CPython and if the version is sufficient,
     otherwise this has no effect). Or you can set it to "py3" or "py2.py3" to
     ignore Python ABI compatibility. The ABI tag is inferred from this tag.
@@ -176,11 +208,11 @@ class WheelSettings:
     root, giving access to "/platlib", "/data", "/headers", and "/scripts".
     """
 
-    license_files: List[str] = dataclasses.field(
-        default_factory=lambda: ["LICEN[CS]E*", "COPYING*", "NOTICE*", "AUTHORS*"]
-    )
+    license_files: Optional[List[str]] = None
     """
     A list of license files to include in the wheel. Supports glob patterns.
+    The default is ``["LICEN[CS]E*", "COPYING*", "NOTICE*", "AUTHORS*"]``.
+    Must not be set if ``project.license-files`` is set.
     """
 
     cmake: bool = True
@@ -254,6 +286,12 @@ class BuildSettings:
     Verbose printout when building.
     """
 
+    requires: List[str] = dataclasses.field(default_factory=list)
+    """
+    Additional ``build-system.requires``. Intended to be used in combination
+    with ``overrides``.
+    """
+
 
 @dataclasses.dataclass
 class InstallSettings:
@@ -326,6 +364,7 @@ class ScikitBuildSettings:
     install: InstallSettings = dataclasses.field(default_factory=InstallSettings)
     generate: List[GenerateSettings] = dataclasses.field(default_factory=list)
     messages: MessagesSettings = dataclasses.field(default_factory=MessagesSettings)
+    search: SearchSettings = dataclasses.field(default_factory=SearchSettings)
 
     metadata: Dict[str, Dict[str, Any]] = dataclasses.field(default_factory=dict)
     """
