@@ -1,4 +1,3 @@
-import sys
 import sysconfig
 import tarfile
 import zipfile
@@ -12,10 +11,11 @@ pytest.importorskip("hatchling")
 @pytest.mark.network
 @pytest.mark.integration
 @pytest.mark.usefixtures("package_hatchling")
-def test_hatchling_sdist(isolated) -> None:
+def test_hatchling_sdist(isolated, tmp_path: Path) -> None:
+    dist = tmp_path / "dist"
     isolated.install("build[virtualenv]")
-    isolated.module("build", "--sdist")
-    (sdist,) = Path("dist").iterdir()
+    isolated.module("build", "--sdist", f"--outdir={dist}")
+    (sdist,) = dist.iterdir()
     assert sdist.name == "hatchling_example-0.1.0.tar.gz"
     with tarfile.open(sdist) as f:
         file_names = set(f.getnames())
@@ -30,9 +30,6 @@ def test_hatchling_sdist(isolated) -> None:
         }
 
 
-@pytest.mark.skipif(
-    sys.version_info < (3, 8), reason="Full hatchling support requires Python 3.8+"
-)
 @pytest.mark.network
 @pytest.mark.compile
 @pytest.mark.configure
@@ -41,12 +38,13 @@ def test_hatchling_sdist(isolated) -> None:
 @pytest.mark.parametrize(
     "build_args", [(), ("--wheel",)], ids=["sdist_to_wheel", "wheel_directly"]
 )
-def test_hatchling_wheel(isolated, build_args) -> None:
+def test_hatchling_wheel(isolated, build_args, tmp_path: Path) -> None:
+    dist = tmp_path / "dist"
     isolated.install("build[virtualenv]", "scikit-build-core", "hatchling", "pybind11")
-    isolated.module("build", "--no-isolation", *build_args)
+    isolated.module("build", "--no-isolation", f"--outdir={dist}", *build_args)
     ext_suffix = sysconfig.get_config_var("EXT_SUFFIX")
 
-    (wheel,) = Path("dist").glob("*.whl")
+    (wheel,) = dist.glob("*.whl")
     with zipfile.ZipFile(wheel) as f:
         file_names = set(f.namelist())
     assert file_names == {
