@@ -1,16 +1,17 @@
 import gzip
 import hashlib
+import inspect
 import shutil
 import sys
 import tarfile
 import time
 import zipfile
+from importlib.metadata import PathDistribution
 from pathlib import Path
 
 import build.util
 import pytest
 
-from scikit_build_core._compat.importlib.metadata import PathDistribution
 from scikit_build_core.build import (
     _file_processor,
     build_sdist,
@@ -28,14 +29,6 @@ something = other
 [gui_scripts]
 guithing = a.b:c
 """
-METADATA = """\
-Metadata-Version: 2.1
-Name: CMake.Example
-Version: 0.0.1
-Requires-Python: >=3.7
-Provides-Extra: test
-Requires-Dist: pytest>=6.0; extra == "test"
-"""
 
 mark_hashes_different = pytest.mark.xfail(
     sys.platform.startswith(("win", "cygwin")),
@@ -50,9 +43,22 @@ def compute_uncompressed_hash(inp: Path) -> str:
 
 
 @pytest.mark.usefixtures("package_simple_pyproject_ext")
-def test_pep517_sdist():
-    dist = Path("dist")
-    out = build_sdist("dist")
+def test_pep517_sdist(tmp_path: Path):
+    expected_metadata = (
+        inspect.cleandoc(
+            """
+            Metadata-Version: 2.2
+            Name: CMake.Example
+            Version: 0.0.1
+            Requires-Python: >=3.8
+            Provides-Extra: test
+            Requires-Dist: pytest>=6.0; extra == "test"
+            """
+        )
+        + "\n\n"
+    )
+    dist = tmp_path / "dist"
+    out = build_sdist(str(dist))
 
     (sdist,) = dist.iterdir()
     assert sdist.name == "cmake_example-0.0.1.tar.gz"
@@ -73,15 +79,15 @@ def test_pep517_sdist():
         pkg_info = f.extractfile("cmake_example-0.0.1/PKG-INFO")
         assert pkg_info
         pkg_info_contents = pkg_info.read().decode()
-        assert pkg_info_contents == METADATA
+        assert pkg_info_contents == expected_metadata
 
 
 @mark_hashes_different
-def test_pep517_sdist_hash(monkeypatch, package_simple_pyproject_ext):
+def test_pep517_sdist_hash(monkeypatch, package_simple_pyproject_ext, tmp_path: Path):
     # Unset SOURCE_DATE_EPOCH in order to guarantee the hash match
     monkeypatch.delenv("SOURCE_DATE_EPOCH", raising=False)
-    dist = Path("dist")
-    out = build_sdist("dist")
+    dist = tmp_path / "dist"
+    out = build_sdist(str(dist))
     sdist = dist / out
     hash = compute_uncompressed_hash(sdist)
     assert hash == package_simple_pyproject_ext.sdist_hash
@@ -93,18 +99,17 @@ def test_pep517_sdist_hash(monkeypatch, package_simple_pyproject_ext):
 
 
 @pytest.mark.usefixtures("package_simple_pyproject_ext")
-def test_pep517_sdist_time_hash():
-    dist = Path("dist")
+def test_pep517_sdist_time_hash(tmp_path: Path):
+    dist = tmp_path / "dist"
 
-    out = build_sdist("dist")
+    out = build_sdist(str(dist))
     sdist = dist / out
     hash1 = hashlib.sha256(sdist.read_bytes()).hexdigest()
 
     time.sleep(2)
     Path("src/main.cpp").touch()
 
-    if Path("dist").is_dir():
-        shutil.rmtree("dist")
+    shutil.rmtree(dist)
 
     out = build_sdist(str(dist))
     sdist = dist / out
@@ -115,17 +120,16 @@ def test_pep517_sdist_time_hash():
 
 
 @pytest.mark.usefixtures("package_simple_pyproject_ext")
-def test_pep517_sdist_time_hash_nonreproducable():
-    dist = Path("dist")
+def test_pep517_sdist_time_hash_nonreproducable(tmp_path: Path):
+    dist = tmp_path / "dist"
 
-    out = build_sdist("dist", {"sdist.reproducible": "false"})
+    out = build_sdist(str(dist), {"sdist.reproducible": "false"})
     sdist = dist / out
     hash1 = hashlib.sha256(sdist.read_bytes()).hexdigest()
 
     time.sleep(2)
 
-    if Path("dist").is_dir():
-        shutil.rmtree("dist")
+    shutil.rmtree(dist)
 
     out = build_sdist(str(dist))
     sdist = dist / out
@@ -138,9 +142,9 @@ def test_pep517_sdist_time_hash_nonreproducable():
 @mark_hashes_different
 @pytest.mark.parametrize("reverse_order", [False, True])
 def test_pep517_sdist_time_hash_set_epoch(
-    monkeypatch, reverse_order, package_simple_pyproject_ext
+    monkeypatch, reverse_order, package_simple_pyproject_ext, tmp_path: Path
 ):
-    dist = Path("dist")
+    dist = tmp_path / "dist"
     monkeypatch.setenv(
         "SOURCE_DATE_EPOCH", package_simple_pyproject_ext.source_date_epoch
     )
@@ -160,8 +164,8 @@ def test_pep517_sdist_time_hash_set_epoch(
     assert hash == package_simple_pyproject_ext.sdist_dated_hash
 
 
-@pytest.mark.compile()
-@pytest.mark.configure()
+@pytest.mark.compile
+@pytest.mark.configure
 @pytest.mark.usefixtures("package_simple_pyproject_script_with_flags")
 @pytest.mark.parametrize(
     ("env_var", "setting"),
@@ -170,11 +174,12 @@ def test_pep517_sdist_time_hash_set_epoch(
         ("SKBUILD_CMAKE_ARGS", "-DCMAKE_C_FLAGS=-DFOO=1 -DBAR="),
     ],
 )
-def test_passing_cxx_flags(monkeypatch, env_var, setting):
+def test_passing_cxx_flags(monkeypatch, env_var, setting, tmp_path: Path):
     # Note: This is sensitive to the types of quotes for SKBUILD_CMAKE_ARGS
     monkeypatch.setenv(env_var, setting)
-    build_wheel("dist", {"cmake.targets": ["cmake_example"]})  # Could leave empty
-    (wheel,) = Path("dist").glob("cmake_example-0.0.1-py3-none-*.whl")
+    dist = tmp_path / "dist"
+    build_wheel(str(dist), {"cmake.targets": ["cmake_example"]})  # Could leave empty
+    (wheel,) = dist.glob("cmake_example-0.0.1-py3-none-*.whl")
     with zipfile.ZipFile(wheel) as f:
         file_names = set(f.namelist())
 
@@ -189,12 +194,14 @@ def test_passing_cxx_flags(monkeypatch, env_var, setting):
     }
 
 
-@pytest.mark.compile()
-@pytest.mark.configure()
+@pytest.mark.compile
+@pytest.mark.configure
 @pytest.mark.usefixtures("package_simple_pyproject_ext")
-def test_pep517_wheel(virtualenv):
-    dist = Path("dist")
-    out = build_wheel("dist", {"cmake.targets": ["cmake_example"]})  # Could leave empty
+def test_pep517_wheel(virtualenv, tmp_path: Path):
+    dist = tmp_path / "dist"
+    out = build_wheel(
+        str(dist), {"cmake.targets": ["cmake_example"]}
+    )  # Could leave empty
     (wheel,) = dist.glob("cmake_example-0.0.1-*.whl")
     assert wheel == dist / out
 
@@ -220,10 +227,10 @@ def test_pep517_wheel(virtualenv):
 
     print(entry_points == ENTRYPOINTS)
     assert 'Requires-Dist: pytest>=6.0; extra == "test"' in metadata
-    assert "Metadata-Version: 2.1" in metadata
+    assert "Metadata-Version: 2.2" in metadata
     assert "Name: CMake.Example" in metadata
     assert "Version: 0.0.1" in metadata
-    assert "Requires-Python: >=3.7" in metadata
+    assert "Requires-Python: >=3.8" in metadata
     assert "Provides-Extra: test" in metadata
 
     virtualenv.install(wheel)
@@ -239,12 +246,12 @@ def test_pep517_wheel(virtualenv):
     assert add.strip() == "3"
 
 
-@pytest.mark.compile()
-@pytest.mark.configure()
+@pytest.mark.compile
+@pytest.mark.configure
 @pytest.mark.usefixtures("package_simple_pyproject_source_dir")
-def test_pep517_wheel_source_dir(virtualenv):
-    dist = Path("dist")
-    out = build_wheel("dist", config_settings={"skbuild.wheel.build-tag": "1foo"})
+def test_pep517_wheel_source_dir(virtualenv, tmp_path: Path):
+    dist = tmp_path / "dist"
+    out = build_wheel(str(dist), config_settings={"skbuild.wheel.build-tag": "1foo"})
     (wheel,) = dist.glob("cmake_example-0.0.1-*.whl")
     assert wheel == dist / out
 
@@ -273,10 +280,10 @@ def test_pep517_wheel_source_dir(virtualenv):
 
     print(entry_points == ENTRYPOINTS)
     assert 'Requires-Dist: pytest>=6.0; extra == "test"' in metadata
-    assert "Metadata-Version: 2.1" in metadata
+    assert "Metadata-Version: 2.2" in metadata
     assert "Name: CMake.Example" in metadata
     assert "Version: 0.0.1" in metadata
-    assert "Requires-Python: >=3.7" in metadata
+    assert "Requires-Python: >=3.8" in metadata
     assert "Provides-Extra: test" in metadata
 
     assert "Build: 1foo" in wheel_metadata
@@ -298,20 +305,19 @@ def test_pep517_wheel_source_dir(virtualenv):
 
 
 @pytest.mark.skip(reason="Doesn't work yet")
-@pytest.mark.compile()
-@pytest.mark.configure()
-def test_pep517_wheel_time_hash(monkeypatch):
+@pytest.mark.compile
+@pytest.mark.configure
+def test_pep517_wheel_time_hash(monkeypatch, tmp_path: Path):
     monkeypatch.setenv("SOURCE_DATE_EPOCH", "12345")
-    dist = Path("dist")
-    out = build_wheel("dist")
+    dist = tmp_path / "dist"
+    out = build_wheel(str(dist))
     wheel = dist / out
     hash1 = hashlib.sha256(wheel.read_bytes()).hexdigest()
 
     time.sleep(2)
     Path("src/main.cpp").touch()
 
-    if Path("dist").is_dir():
-        shutil.rmtree("dist")
+    shutil.rmtree(dist)
 
     out = build_wheel(str(dist))
     wheel = dist / out
@@ -325,10 +331,10 @@ def test_pep517_wheel_time_hash(monkeypatch):
 def test_prepare_metdata_for_build_wheel():
     metadata = build.util.project_wheel_metadata(str(Path.cwd()), isolated=False)
     answer = {
-        "Metadata-Version": "2.1",
+        "Metadata-Version": "2.2",
         "Name": "CMake.Example",
         "Version": "0.0.1",
-        "Requires-Python": ">=3.7",
+        "Requires-Python": ">=3.8",
         "Provides-Extra": "test",
         "Requires-Dist": 'pytest>=6.0; extra == "test"',
     }
@@ -347,10 +353,10 @@ def test_prepare_metdata_for_build_wheel_by_hand(tmp_path):
     print("Metadata dir:", (mddir / out).resolve())
     metadata = PathDistribution(mddir / out).metadata
     answer = {
-        "Metadata-Version": "2.1",
+        "Metadata-Version": "2.2",
         "Name": "CMake.Example",
         "Version": "0.0.1",
-        "Requires-Python": ">=3.7",
+        "Requires-Python": ">=3.8",
         "Provides-Extra": "test",
         "Requires-Dist": 'pytest>=6.0; extra == "test"',
     }
@@ -359,3 +365,82 @@ def test_prepare_metdata_for_build_wheel_by_hand(tmp_path):
         assert metadata.get(k, None) == b
 
     assert len(metadata) == len(answer)
+
+
+@pytest.mark.usefixtures("package_pep639_pure")
+def test_pep639_license_files_metadata():
+    metadata = build.util.project_wheel_metadata(str(Path.cwd()), isolated=False)
+    answer = {
+        "Metadata-Version": ["2.4"],
+        "Name": ["pep639_pure"],
+        "Version": ["0.1.0"],
+        "License-Expression": ["MIT"],
+        "License-File": ["LICENSE1.txt", "nested/more/LICENSE2.txt"],
+    }
+
+    for k, b in answer.items():
+        assert metadata.get_all(k, None) == b
+
+    assert len(metadata) == sum(len(v) for v in answer.values())
+
+
+@pytest.mark.usefixtures("package_pep639_pure")
+def test_pep639_license_files_sdist(tmp_path: Path):
+    expected_metadata = (
+        inspect.cleandoc(
+            """
+                Metadata-Version: 2.4
+                Name: pep639_pure
+                Version: 0.1.0
+                License-Expression: MIT
+                License-File: LICENSE1.txt
+                License-File: nested/more/LICENSE2.txt
+            """
+        )
+        + "\n\n"
+    )
+
+    dist = tmp_path / "dist"
+    out = build_sdist(str(dist))
+
+    (sdist,) = dist.iterdir()
+    assert sdist.name == "pep639_pure-0.1.0.tar.gz"
+    assert sdist == dist / out
+
+    with tarfile.open(sdist) as f:
+        file_names = set(f.getnames())
+        assert file_names == {
+            f"pep639_pure-0.1.0/{x}"
+            for x in (
+                "pyproject.toml",
+                "PKG-INFO",
+                "LICENSE1.txt",
+                "nested/more/LICENSE2.txt",
+            )
+        }
+        pkg_info = f.extractfile("pep639_pure-0.1.0/PKG-INFO")
+        assert pkg_info
+        pkg_info_contents = pkg_info.read().decode()
+        assert pkg_info_contents == expected_metadata
+
+
+@pytest.mark.usefixtures("package_pep639_pure")
+def test_pep639_license_files_wheel(tmp_path: Path):
+    dist = tmp_path / "dist"
+    out = build_wheel(str(dist), {})
+    (wheel,) = dist.glob("pep639_pure-0.1.0-*.whl")
+    assert wheel == dist / out
+
+    with zipfile.ZipFile(wheel) as zf:
+        file_paths = {Path(p) for p in zf.namelist()}
+        with zf.open("pep639_pure-0.1.0.dist-info/METADATA") as f:
+            metadata = f.read().decode("utf-8")
+
+    assert Path("pep639_pure-0.1.0.dist-info/licenses/LICENSE1.txt") in file_paths
+    assert (
+        Path("pep639_pure-0.1.0.dist-info/licenses/nested/more/LICENSE2.txt")
+        in file_paths
+    )
+
+    assert "LICENSE1.txt" in metadata
+    assert "nested/more/LICENSE2.txt" in metadata
