@@ -11,7 +11,7 @@ from scikit_build_core.build import build_editable
 
 @pytest.fixture(params=["redirect", "inplace"])
 def editable_mode(request: pytest.FixtureRequest) -> str:
-    return typing.cast(str, request.param)
+    return typing.cast("str", request.param)
 
 
 # TODO: figure out why gmake is reporting no rule to make simple_pure.cpp
@@ -23,9 +23,9 @@ def editable_mode(request: pytest.FixtureRequest) -> str:
     reason="No idea why this fails on Cygwin",
 )
 @pytest.mark.usefixtures("package_simplest_c")
-def test_pep660_wheel(editable_mode: str):
-    dist = Path("dist")
-    out = build_editable("dist", {"editable.mode": editable_mode})
+def test_pep660_wheel(editable_mode: str, tmp_path: Path):
+    dist = tmp_path / "dist"
+    out = build_editable(str(dist), {"editable.mode": editable_mode})
     (wheel,) = dist.glob("simplest-0.0.1-*.whl")
     assert wheel == dist / out
 
@@ -45,7 +45,7 @@ def test_pep660_wheel(editable_mode: str):
         assert "_simplest_editable.py" not in file_names
     assert "_simplest_editable.pth" in file_names
 
-    assert "Metadata-Version: 2.1" in metadata
+    assert "Metadata-Version: 2.2" in metadata
     assert "Name: simplest" in metadata
     assert "Version: 0.0.1" in metadata
 
