@@ -8,20 +8,20 @@ pytestmark = pytest.mark.setuptools
 
 
 # TODO: work out why this fails on Cygwin
-@pytest.mark.compile()
-@pytest.mark.configure()
-@pytest.mark.integration()
-@pytest.mark.broken_on_urct()
+@pytest.mark.compile
+@pytest.mark.configure
+@pytest.mark.integration
+@pytest.mark.broken_on_urct
 @pytest.mark.xfail(
     sys.platform.startswith("cygwin"),
     reason="Cygwin fails here with ld errors",
     strict=False,
 )
 @pytest.mark.usefixtures("package_simple_setuptools_ext")
-def test_pep518_wheel(isolated):
-    dist = Path("dist")
+def test_pep518_wheel(isolated, tmp_path: Path):
+    dist = tmp_path / "dist"
     isolated.install("build[virtualenv]")
-    isolated.module("build", "--wheel")
+    isolated.module("build", "--wheel", f"--outdir={dist}")
     (wheel,) = dist.iterdir()
     assert "cmake_example-0.0.1" in wheel.name
     assert wheel.suffix == ".whl"
@@ -46,10 +46,10 @@ def test_pep518_wheel(isolated):
     assert add == "3"
 
 
-@pytest.mark.compile()
-@pytest.mark.configure()
-@pytest.mark.integration()
-@pytest.mark.broken_on_urct()
+@pytest.mark.compile
+@pytest.mark.configure
+@pytest.mark.integration
+@pytest.mark.broken_on_urct
 @pytest.mark.xfail(
     sys.platform.startswith("cygwin"),
     reason="Cygwin fails here with ld errors",
